==> auth0-lock-11.7.2.jar: META-INF/resources/webjars/auth0-lock/11.7.2/lib/i18n/zh-tw.js <==
'use strict';

exports.__esModule = true;
// This file was automatically translated.
// Feel free to submit a PR if you find a more accurate translation.

exports.default = {
  error: {
    forgotPassword: {
      too_many_requests: '嘗試登入次數太多，請稍後再試。',
      'lock.fallback': '對不起，修改密碼時發生錯誤。',
      enterprise_email: '您的電子郵件域名是企業身份提供者的一部分。要重置您的密碼，請聯繫您的安全管理員。'
    },
    login: {
      blocked_user: '帳號已被鎖定。',
      invalid_user_password: '密碼錯誤',
      'lock.fallback': '對不起，登入時發生錯誤。',
      'lock.invalid_code': '代碼錯誤。',
      'lock.invalid_email_password': '電子郵件或密碼錯誤。',
      'lock.invalid_username_password': '帳號或密碼錯誤。',
      'lock.network': '無法連線到伺服器，請檢查網路連線後重試。',
      'lock.popup_closed': '彈出視窗被關閉，請重試。',
      'lock.unauthorized': '權限不足，請重試。',
      password_change_required: '因為是第一次登入或密碼已逾期，請更新密碼。',
      password_leaked: '由於您的密碼已在其他網站洩漏，帳號已被鎖定，請查看電子郵件解鎖。',
      too_many_attempts: '由於登入異常頻繁，您的帳號已被鎖定。',
      'lock.mfa_registration_required': '多因素認證是必需的，但沒有登記您的設備。在移動之前，請報名參加吧。',
      'lock.mfa_invalid_code': '錯誤代碼。請再試一次。',
      session_missing: '無法完成身份驗證請求。請關閉所有打開的對話框後，再試一次',
      'hrd.not_matching_email': '請使用您的公司電子郵件登錄。'
    },
    passwordless: {
      'bad.email': '電子信箱錯誤',
      'bad.phone_number': '手機號碼錯誤。',
      'lock.fallback': '對不起，發生錯誤。'
    },
    signUp: {
      invalid_password: '密碼錯誤',
      'lock.fallback': '對不起，註冊時發生錯誤。',
      password_dictionary_error: '密碼過於常見。',
      password_no_user_info_error: '密碼中出現帳號訊息。',
      password_strength_error: '密碼太簡單。',
      user_exists: '該使用者已存在。',
      username_exists: '該帳號已存在。'
    }
  },
  success: {
    logIn: '登入成功',
    forgotPassword: '重設密碼的電子郵件已送出',
    magicLink: '已送出超連結以登入到<br /> %s ',
    signUp: '感謝您的註冊。'
  },
  blankErrorHint: '不能是空白',
  codeInputPlaceholder: '您的代碼',
  databaseEnterpriseLoginInstructions: '',
  databaseEnterpriseAlternativeLoginInstructions: '或',
  databaseSignUpInstructions: '',
  databaseAlternativeSignUpInstructions: '或',
  emailInputPlaceholder: 'yours@example.com',
  enterpriseLoginIntructions: '請用您的公司帳號登入。',
  enterpriseActiveLoginInstructions: '請輸入您在 %s 的公司帳號。',
  failedLabel: '失敗！',
  forgotPasswordAction: '忘記密碼？',
  forgotPasswordInstructions: '請輸入電子郵件信箱，我們將送出重設密碼的信件。',
  forgotPasswordSubmitLabel: '送出電子郵件',
  invalidErrorHint: '錯誤',
  lastLoginInstructions: '上次登入帳號為',
  loginAtLabel: '登入 %s',
  loginLabel: '登入',
  loginSubmitLabel: '登入',
  loginWithLabel: '用 %s 登入',
  notYourAccountAction: '這不是您的帳號？',
  passwordInputPlaceholder: '您的密碼',
  passwordStrength: {
    containsAtLeast: '至少包含 %d 個以下 %d 種字元：',
    identicalChars: '不能多於 %d 個相同的字元在同一行（例如，不允許出現 "%s" ）',
    nonEmpty: '密碼不能為空',
    numbers: '數字（如 0-9）',
    lengthAtLeast: '最少 %d 個字元',
    lowerCase: '小寫字母（a-z）',
    shouldContain: '應包含：',
    specialCharacters: '特殊字元（如 !@#$%^&*）',
    upperCase: '大寫字母（A-Z）'
  },
  passwordlessEmailAlternativeInstructions: '您還可以使用電子郵件信箱登入<br>或是建立帳號',
  passwordlessEmailCodeInstructions: '代碼已透過電子郵件送到 %s 。',
  passwordlessEmailInstructions: '輸入電子郵件信箱登入<br>或是建立帳號。',
  passwordlessSMSAlternativeInstructions: '您還可以使用手機號碼登入<br>或是建立帳號。',
  passwordlessSMSCodeInstructions: '代碼已透過簡訊發送到<br> %s 。',
  passwordlessSMSInstructions: '輸入手機號碼登入<br>或是建立帳號',
  phoneNumberInputPlaceholder: '您的手機號碼',
  resendCodeAction: '沒有收到代碼？',
  resendLabel: '重新發送',
  resendingLabel: '重新發送中....',
  retryLabel: '重試',
  sentLabel: '發送！',
  signUpLabel: '註冊',
  signUpSubmitLabel: '註冊',
  signUpTerms: '',
  signUpWithLabel: '透過 %s 註冊',
  socialLoginInstructions: '',
  socialSignUpInstructions: '',
  ssoEnabled: '單一簽入已啟用',
  submitLabel: '送出',
  unrecoverableError: '發生錯誤。<br />請聯絡技術人員。',
  usernameFormatErrorHint: '使用 %d-%d 字母，數字和以下字符：“_”，“。”，“+”，“ - ”',
  usernameInputPlaceholder: '您的帳號',
  usernameOrEmailInputPlaceholder: '帳號 / 電子郵件信箱',
  title: 'Auth0',
  welcome: '歡迎 %s ！',
  windowsAuthInstructions: '您已連接到公司網路&hellip;',
  windowsAuthLabel: 'Windows 認證',
  forgotPasswordTitle: '重置你的密碼',
  signupTitle: '註冊',
  mfaInputPlaceholder: '碼',
  mfaLoginTitle: '兩步驟驗證',
  mfaLoginInstructions: '請輸入您的移動應用程序生成的驗證碼。',
  mfaSubmitLabel: '登錄',
  mfaCodeErrorHint: '使用%d編號',
  showPassword: '顯示密碼'
};

==> auth0-lock-11.14.1.jar: META-INF/resources/webjars/auth0-lock/11.14.1/lib/i18n/zh-tw.js <==
'use strict';

exports.__esModule = true;
// This file was automatically translated.
// Feel free to submit a PR if you find a more accurate translation.

exports.default = {
  error: {
    forgotPassword: {
      too_many_requests: '嘗試登入次數太多，請稍後再試。',
      'lock.fallback': '對不起，修改密碼時發生錯誤。',
      enterprise_email: '您的電子郵件域名是企業身份提供者的一部分。要重置您的密碼，請聯繫您的安全管理員。'
    },
    login: {
      blocked_user: '帳號已被鎖定。',
      invalid_user_password: '密碼錯誤',
      'lock.fallback': '對不起，登入時發生錯誤。',
      'lock.invalid_code': '代碼錯誤。',
      'lock.invalid_email_password': '電子郵件或密碼錯誤。',
      'lock.invalid_username_password': '帳號或密碼錯誤。',
      'lock.network': '無法連線到伺服器，請檢查網路連線後重試。',
      'lock.popup_closed': '彈出視窗被關閉，請重試。',
      'lock.unauthorized': '權限不足，請重試。',
      password_change_required: '因為是第一次登入或密碼已逾期，請更新密碼。',
      password_leaked: '由於您的密碼已在其他網站洩漏，帳號已被鎖定，請查看電子郵件解鎖。',
      too_many_attempts: '由於登入異常頻繁，您的帳號已被鎖定。',
      'lock.mfa_registration_required': '多因素認證是必需的，但沒有登記您的設備。在移動之前，請報名參加吧。',
      'lock.mfa_invalid_code': '錯誤代碼。請再試一次。',
      session_missing: '無法完成身份驗證請求。請關閉所有打開的對話框後，再試一次',
      'hrd.not_matching_email': '請使用您的公司電子郵件登錄。'
    },
    passwordless: {
      'bad.email': '電子信箱錯誤',
      'bad.phone_number': '手機號碼錯誤。',
      'lock.fallback': '對不起，發生錯誤。'
    },
    signUp: {
      invalid_password: '密碼錯誤',
      'lock.fallback': '對不起，註冊時發生錯誤。',
      password_dictionary_error: '密碼過於常見。',
      password_no_user_info_error: '密碼中出現帳號訊息。',
      password_strength_error: '密碼太簡單。',
      user_exists: '該使用者已存在。',
      username_exists: '該帳號已存在。'
    }
  },
  success: {
    logIn: '登入成功',
    forgotPassword: '重設密碼的電子郵件已送出',
    magicLink: '已送出超連結以登入到<br /> %s ',
    signUp: '感謝您的註冊。'
  },
  blankErrorHint: '不能是空白',
  codeInputPlaceholder: '您的代碼',
  databaseEnterpriseLoginInstructions: '',
  databaseEnterpriseAlternativeLoginInstructions: '或',
  databaseSignUpInstructions: '',
  databaseAlternativeSignUpInstructions: '或',
  emailInputPlaceholder: 'yours@example.com',
  enterpriseLoginIntructions: '請用您的公司帳號登入。',
  enterpriseActiveLoginInstructions: '請輸入您在 %s 的公司帳號。',
  failedLabel: '失敗！',
  forgotPasswordAction: '忘記密碼？',
  forgotPasswordInstructions: '請輸入電子郵件信箱，我們將送出重設密碼的信件。',
  forgotPasswordSubmitLabel: '送出電子郵件',
  invalidErrorHint: '錯誤',
  lastLoginInstructions: '上次登入帳號為',
  loginAtLabel: '登入 %s',
  loginLabel: '登入',
  loginSubmitLabel: '登入',
  loginWithLabel: '用 %s 登入',
  notYourAccountAction: '這不是您的帳號？',
  passwordInputPlaceholder: '您的密碼',
  passwordStrength: {
    containsAtLeast: '至少包含 %d 個以下 %d 種字元：',
    identicalChars: '不能多於 %d 個相同的字元在同一行（例如，不允許出現 "%s" ）',
    nonEmpty: '密碼不能為空',
    numbers: '數字（如 0-9）',
    lengthAtLeast: '最少 %d 個字元',
    lowerCase: '小寫字母（a-z）',
    shouldContain: '應包含：',
    specialCharacters: '特殊字元（如 !@#$%^&*）',
    upperCase: '大寫字母（A-Z）'
  },
  passwordlessEmailAlternativeInstructions: '您還可以使用電子郵件信箱登入<br>或是建立帳號',
  passwordlessEmailCodeInstructions: '代碼已透過電子郵件送到 %s 。',
  passwordlessEmailInstructions: '輸入電子郵件信箱登入<br>或是建立帳號。',
  passwordlessSMSAlternativeInstructions: '您還可以使用手機號碼登入<br>或是建立帳號。',
  passwordlessSMSCodeInstructions: '代碼已透過簡訊發送到<br> %s 。',
  passwordlessSMSInstructions: '輸入手機號碼登入<br>或是建立帳號',
  phoneNumberInputPlaceholder: '您的手機號碼',
  resendCodeAction: '沒有收到代碼？',
  resendLabel: '重新發送',
  resendingLabel: '重新發送中....',
  retryLabel: '重試',
  sentLabel: '發送！',
  signUpLabel: '註冊',
  signUpSubmitLabel: '註冊',
  signUpWithLabel: '透過 %s 註冊',
  socialLoginInstructions: '',
  socialSignUpInstructions: '',
  ssoEnabled: '單一簽入已啟用',
  submitLabel: '送出',
  unrecoverableError: '發生錯誤。<br />請聯絡技術人員。',
  usernameFormatErrorHint: '使用 %d-%d 字母，數字和以下字符：“_”，“。”，“+”，“ - ”',
  usernameInputPlaceholder: '您的帳號',
  usernameOrEmailInputPlaceholder: '帳號 / 電子郵件信箱',
  title: 'Auth0',
  welcome: '歡迎 %s ！',
  windowsAuthInstructions: '您已連接到公司網路&hellip;',
  windowsAuthLabel: 'Windows 認證',
  forgotPasswordTitle: '重置您的密碼',
  signUpTitle: '註冊',
  mfaInputPlaceholder: '碼',
  mfaLoginTitle: '兩步驟驗證',
  mfaLoginInstructions: '請輸入您的移動應用程序生成的驗證碼。',
  mfaSubmitLabel: '登錄',
  mfaCodeErrorHint: '使用%d編號',
  showPassword: '顯示密碼',
  signUpTerms: '註冊即表示您同意我們的服務條款和隱私政策。'
};
